#[non_exhaustive]pub struct DeleteSupportPermitOutput {
pub name: String,
pub arn: String,
pub description: Option<String>,
pub permit: Option<Permit>,
pub status: SupportPermitStatus,
pub signing_key_info: Option<SigningKeyInfo>,
pub created_at: DateTime,
pub support_case_display_id: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the deleted support permit.
arn: StringThe ARN of the deleted support permit.
description: Option<String>The description of the deleted support permit.
permit: Option<Permit>The permit definition of the deleted permit.
status: SupportPermitStatusThe status of the support permit. Returns DELETING.
signing_key_info: Option<SigningKeyInfo>The signing key information for the deleted permit.
created_at: DateTimeThe timestamp when the permit was originally created.
support_case_display_id: Option<String>The display identifier of the support case associated with the deleted permit.
Implementations
Sourceimpl DeleteSupportPermitOutput
impl DeleteSupportPermitOutput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the deleted support permit.
Sourcepub fn status(&self) -> &SupportPermitStatus
pub fn status(&self) -> &SupportPermitStatus
The status of the support permit. Returns DELETING.
Sourcepub fn signing_key_info(&self) -> Option<&SigningKeyInfo>
pub fn signing_key_info(&self) -> Option<&SigningKeyInfo>
The signing key information for the deleted permit.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The timestamp when the permit was originally created.
Sourcepub fn support_case_display_id(&self) -> Option<&str>
pub fn support_case_display_id(&self) -> Option<&str>
The display identifier of the support case associated with the deleted permit.
Sourceimpl DeleteSupportPermitOutput
impl DeleteSupportPermitOutput
Sourcepub fn builder() -> DeleteSupportPermitOutputBuilder
pub fn builder() -> DeleteSupportPermitOutputBuilder
Creates a new builder-style object to manufacture DeleteSupportPermitOutput.