#[non_exhaustive]pub struct GetSupportPermitInput {
pub support_permit_identifier: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.support_permit_identifier: Option<String>The ARN or name of the support permit to retrieve.
Implementations
Sourceimpl GetSupportPermitInput
impl GetSupportPermitInput
Sourcepub fn support_permit_identifier(&self) -> Option<&str>
pub fn support_permit_identifier(&self) -> Option<&str>
The ARN or name of the support permit to retrieve.
Sourceimpl GetSupportPermitInput
impl GetSupportPermitInput
Sourcepub fn builder() -> GetSupportPermitInputBuilder
pub fn builder() -> GetSupportPermitInputBuilder
Creates a new builder-style object to manufacture GetSupportPermitInput.