#[non_exhaustive]pub struct GetSupportPermitOutput {
pub name: String,
pub arn: String,
pub description: Option<String>,
pub permit: Option<Permit>,
pub status: SupportPermitStatus,
pub signing_key_info: Option<SigningKeyInfo>,
pub created_at: DateTime,
pub support_case_display_id: Option<String>,
pub tags: Option<HashMap<String, String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the support permit.
arn: StringThe ARN of the support permit.
description: Option<String>The description of the support permit.
permit: Option<Permit>The permit definition.
status: SupportPermitStatusThe current status of the support permit.
signing_key_info: Option<SigningKeyInfo>The signing key information for the permit.
created_at: DateTimeThe timestamp when the permit was created.
support_case_display_id: Option<String>The display identifier of the support case associated with the permit.
The tags associated with the support permit.
Implementations
Sourceimpl GetSupportPermitOutput
impl GetSupportPermitOutput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the support permit.
Sourcepub fn status(&self) -> &SupportPermitStatus
pub fn status(&self) -> &SupportPermitStatus
The current status of the support permit.
Sourcepub fn signing_key_info(&self) -> Option<&SigningKeyInfo>
pub fn signing_key_info(&self) -> Option<&SigningKeyInfo>
The signing key information for the permit.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The timestamp when the permit was created.
Sourcepub fn support_case_display_id(&self) -> Option<&str>
pub fn support_case_display_id(&self) -> Option<&str>
The display identifier of the support case associated with the permit.
The tags associated with the support permit.
Sourceimpl GetSupportPermitOutput
impl GetSupportPermitOutput
Sourcepub fn builder() -> GetSupportPermitOutputBuilder
pub fn builder() -> GetSupportPermitOutputBuilder
Creates a new builder-style object to manufacture GetSupportPermitOutput.