pub struct Client { /* private fields */ }Expand description
Client for SupportAuthZ
Client for invoking operations on SupportAuthZ. Each operation on SupportAuthZ is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_supportauthz::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_supportauthz::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the CreateSupportPermit operation has
a Client::create_support_permit, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.create_support_permit()
.name("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn create_support_permit(&self) -> CreateSupportPermitFluentBuilder
pub fn create_support_permit(&self) -> CreateSupportPermitFluentBuilder
Constructs a fluent builder for the CreateSupportPermit operation.
- The fluent builder is configurable:
permit(Permit)/set_permit(Option<Permit>):
required: trueThe permit definition specifying the actions, resources, and time-window conditions that the support operator is authorized to use.
name(impl Into<String>)/set_name(Option<String>):
required: trueA customer-chosen name for the support permit. Must be between 1 and 256 alphanumeric characters.
description(impl Into<String>)/set_description(Option<String>):
required: falseA human-readable description of why this permit is being created. Maximum length of 1024 characters.
signing_key_info(SigningKeyInfo)/set_signing_key_info(Option<SigningKeyInfo>):
required: trueThe signing key information used to sign the permit. Must reference an AWS KMS key with key usage SIGN_VERIFY and key spec ECC_NIST_P384.
support_case_display_id(impl Into<String>)/set_support_case_display_id(Option<String>):
required: falseThe display identifier of the AWS Support case associated with this permit.
client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service returns the existing permit without creating a duplicate.
tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: falseThe tags to associate with the support permit on creation.
- On success, responds with
CreateSupportPermitOutputwith field(s):name(String):The name of the support permit.
arn(String):The Amazon Resource Name (ARN) of the support permit.
description(Option<String>):The description of the support permit.
permit(Option<Permit>):The permit definition.
status(SupportPermitStatus):The current status of the support permit.
signing_key_info(Option<SigningKeyInfo>):The signing key information for the permit.
created_at(DateTime):The timestamp when the permit was created.
support_case_display_id(Option<String>):The display identifier of the support case associated with the permit.
tags(Option<HashMap::<String, String>>):The tags associated with the support permit.
- On failure, responds with
SdkError<CreateSupportPermitError>
Sourceimpl Client
impl Client
Sourcepub fn delete_support_permit(&self) -> DeleteSupportPermitFluentBuilder
pub fn delete_support_permit(&self) -> DeleteSupportPermitFluentBuilder
Constructs a fluent builder for the DeleteSupportPermit operation.
- The fluent builder is configurable:
support_permit_identifier(impl Into<String>)/set_support_permit_identifier(Option<String>):
required: trueThe Amazon Resource Name (ARN) or name of the support permit to delete.
- On success, responds with
DeleteSupportPermitOutputwith field(s):name(String):The name of the deleted support permit.
arn(String):The ARN of the deleted support permit.
description(Option<String>):The description of the deleted support permit.
permit(Option<Permit>):The permit definition of the deleted permit.
status(SupportPermitStatus):The status of the support permit. Returns DELETING.
signing_key_info(Option<SigningKeyInfo>):The signing key information for the deleted permit.
created_at(DateTime):The timestamp when the permit was originally created.
support_case_display_id(Option<String>):The display identifier of the support case associated with the deleted permit.
- On failure, responds with
SdkError<DeleteSupportPermitError>
Sourceimpl Client
impl Client
Sourcepub fn get_action(&self) -> GetActionFluentBuilder
pub fn get_action(&self) -> GetActionFluentBuilder
Constructs a fluent builder for the GetAction operation.
- The fluent builder is configurable:
action(impl Into<String>)/set_action(Option<String>):
required: trueThe name of the support action to retrieve.
- On success, responds with
GetActionOutputwith field(s):action(String):The name of the support action.
service(String):The AWS service associated with the support action.
description(String):A description of what the support action does.
- On failure, responds with
SdkError<GetActionError>
Sourceimpl Client
impl Client
Sourcepub fn get_support_permit(&self) -> GetSupportPermitFluentBuilder
pub fn get_support_permit(&self) -> GetSupportPermitFluentBuilder
Constructs a fluent builder for the GetSupportPermit operation.
- The fluent builder is configurable:
support_permit_identifier(impl Into<String>)/set_support_permit_identifier(Option<String>):
required: trueThe ARN or name of the support permit to retrieve.
- On success, responds with
GetSupportPermitOutputwith field(s):name(String):The name of the support permit.
arn(String):The ARN of the support permit.
description(Option<String>):The description of the support permit.
permit(Option<Permit>):The permit definition.
status(SupportPermitStatus):The current status of the support permit.
signing_key_info(Option<SigningKeyInfo>):The signing key information for the permit.
created_at(DateTime):The timestamp when the permit was created.
support_case_display_id(Option<String>):The display identifier of the support case associated with the permit.
tags(Option<HashMap::<String, String>>):The tags associated with the support permit.
- On failure, responds with
SdkError<GetSupportPermitError>
Sourceimpl Client
impl Client
Sourcepub fn list_actions(&self) -> ListActionsFluentBuilder
pub fn list_actions(&self) -> ListActionsFluentBuilder
Constructs a fluent builder for the ListActions operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseThe token for the next page of results.
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return in a single call. Valid range is 1 to 100.
service(impl Into<String>)/set_service(Option<String>):
required: trueThe name of the AWS service for which to list available support actions.
- On success, responds with
ListActionsOutputwith field(s):action_summaries(Vec::<ActionSummary>):The list of support actions.
next_token(Option<String>):The token for the next page of results, or null if there are no more results.
- On failure, responds with
SdkError<ListActionsError>
Sourceimpl Client
impl Client
Sourcepub fn list_support_permit_requests(
&self,
) -> ListSupportPermitRequestsFluentBuilder
pub fn list_support_permit_requests( &self, ) -> ListSupportPermitRequestsFluentBuilder
Constructs a fluent builder for the ListSupportPermitRequests operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseThe token for the next page of results.
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return in a single call. Valid range is 1 to 100.
support_case_display_id(impl Into<String>)/set_support_case_display_id(Option<String>):
required: falseFilters the results by support case display identifier.
- On success, responds with
ListSupportPermitRequestsOutputwith field(s):support_permit_requests(Vec::<SupportPermitRequest>):The list of permit requests.
next_token(Option<String>):The token for the next page of results, or null if there are no more results.
- On failure, responds with
SdkError<ListSupportPermitRequestsError>
Sourceimpl Client
impl Client
Sourcepub fn list_support_permits(&self) -> ListSupportPermitsFluentBuilder
pub fn list_support_permits(&self) -> ListSupportPermitsFluentBuilder
Constructs a fluent builder for the ListSupportPermits operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseThe token for the next page of results.
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return in a single call. Valid range is 1 to 100.
support_permit_statuses(SupportPermitStatus)/set_support_permit_statuses(Option<Vec::<SupportPermitStatus>>):
required: falseFilters the results by support permit status. Valid values: ACTIVE, INACTIVE, DELETING.
- On success, responds with
ListSupportPermitsOutputwith field(s):support_permits(Vec::<SupportPermitSummary>):The list of support permits.
next_token(Option<String>):The token for the next page of results, or null if there are no more results.
- On failure, responds with
SdkError<ListSupportPermitsError>
Sourceimpl Client
impl Client
Constructs a fluent builder for the ListTagsForResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe ARN of the resource to list tags for.
- On success, responds with
ListTagsForResourceOutputwith field(s):tags(Option<HashMap::<String, String>>):The tags associated with the resource.
- On failure, responds with
SdkError<ListTagsForResourceError>
Sourceimpl Client
impl Client
Sourcepub fn reject_support_permit_request(
&self,
) -> RejectSupportPermitRequestFluentBuilder
pub fn reject_support_permit_request( &self, ) -> RejectSupportPermitRequestFluentBuilder
Constructs a fluent builder for the RejectSupportPermitRequest operation.
- The fluent builder is configurable:
request_arn(impl Into<String>)/set_request_arn(Option<String>):
required: trueThe ARN of the permit request to reject.
- On success, responds with
RejectSupportPermitRequestOutputwith field(s):request_arn(String):The ARN of the rejected permit request.
- On failure, responds with
SdkError<RejectSupportPermitRequestError>
Sourceimpl Client
impl Client
Sourcepub fn tag_resource(&self) -> TagResourceFluentBuilder
pub fn tag_resource(&self) -> TagResourceFluentBuilder
Constructs a fluent builder for the TagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe ARN of the resource to tag.
tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: trueThe tags to add to the resource. Maximum of 50 tags.
- On success, responds with
TagResourceOutput - On failure, responds with
SdkError<TagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn untag_resource(&self) -> UntagResourceFluentBuilder
pub fn untag_resource(&self) -> UntagResourceFluentBuilder
Constructs a fluent builder for the UntagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe ARN of the resource to untag.
tag_keys(impl Into<String>)/set_tag_keys(Option<Vec::<String>>):
required: trueThe tag keys to remove from the resource.
- On success, responds with
UntagResourceOutput - On failure, responds with
SdkError<UntagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.