#[non_exhaustive]pub struct CreateSupportPermitInput {
pub permit: Option<Permit>,
pub name: Option<String>,
pub description: Option<String>,
pub signing_key_info: Option<SigningKeyInfo>,
pub support_case_display_id: Option<String>,
pub client_token: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.permit: Option<Permit>The permit definition specifying the actions, resources, and time-window conditions that the support operator is authorized to use.
name: Option<String>A customer-chosen name for the support permit. Must be between 1 and 256 alphanumeric characters.
description: Option<String>A human-readable description of why this permit is being created. Maximum length of 1024 characters.
signing_key_info: Option<SigningKeyInfo>The signing key information used to sign the permit. Must reference an AWS KMS key with key usage SIGN_VERIFY and key spec ECC_NIST_P384.
support_case_display_id: Option<String>The display identifier of the AWS Support case associated with this permit.
client_token: Option<String>A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service returns the existing permit without creating a duplicate.
The tags to associate with the support permit on creation.
Implementations
Sourceimpl CreateSupportPermitInput
impl CreateSupportPermitInput
Sourcepub fn permit(&self) -> Option<&Permit>
pub fn permit(&self) -> Option<&Permit>
The permit definition specifying the actions, resources, and time-window conditions that the support operator is authorized to use.
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
A customer-chosen name for the support permit. Must be between 1 and 256 alphanumeric characters.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A human-readable description of why this permit is being created. Maximum length of 1024 characters.
Sourcepub fn signing_key_info(&self) -> Option<&SigningKeyInfo>
pub fn signing_key_info(&self) -> Option<&SigningKeyInfo>
The signing key information used to sign the permit. Must reference an AWS KMS key with key usage SIGN_VERIFY and key spec ECC_NIST_P384.
Sourcepub fn support_case_display_id(&self) -> Option<&str>
pub fn support_case_display_id(&self) -> Option<&str>
The display identifier of the AWS Support case associated with this permit.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service returns the existing permit without creating a duplicate.
The tags to associate with the support permit on creation.
Sourceimpl CreateSupportPermitInput
impl CreateSupportPermitInput
Sourcepub fn builder() -> CreateSupportPermitInputBuilder
pub fn builder() -> CreateSupportPermitInputBuilder
Creates a new builder-style object to manufacture CreateSupportPermitInput.